#!/bin/sh
FGREP="/usr/bin/fgrep"
SWATP="/usr/sbin/swat"
PIDOF="/bin/pidof"
SRVIS="swat             901/tcp"
INETD="swat     stream  tcp     nowait.400      root    /usr/sbin/swat   swat"
# swat
if !($FGREP swat /etc/services > /dev/null); then
    echo "$SRVIS" >> /etc/services
fi
# inetd
if !($FGREP $SWATP /etc/inetd.conf > /dev/null); then
    echo "$INETD" >> /etc/inetd.conf
fi
#
kill -HUP `$PIDOF inetd`
